#ifndef DS1820_H
	#define DS1820_H



#include <avr/io.h>

#include <util/delay.h>			// One-Wire Timing wird mit delay erzeugt
#include <avr/interrupt.h>		// One-Wire FUnktionen mssen teilweise Interrupts sperren


#include <avr/pgmspace.h>



#define OW_PORT		PORTA
#define OW_DDR		DDRA
#define OW_INPUT	PINA
#define OW_PIN		PA2


// Sensortypen:
#define DS18B20		0x28
#define DS18S20		0x10


#define USE_READ_ROM		// einkommentieren, wenn ow_read_rom() bentigt wird (um Slave ID herauszufinden)


uint8_t ow_reset();	//erzeugt einen Reset Puls


uint8_t ow_read_rom(uint8_t* data);		//liest den ROM-Code des Slaves ein

// startet die Temperaturmessung fr einen am Bus angeschlossenen Sensor (arbeitet mit SkipROM Befehl)
void DS18B20_start_measure();

// sensor_type gibt an, ob es sich um einen DS18 B 20 (0x28) oder einen DS18 S 20 (0x10) handelt
// entsprechend wird die Temperatur berechnet
// Rckgabewert: Temperatur * 10	--> z.B. 123 = 12,3 C
// Rckgabewert bei CRC-Fehler: CRC_ERROR
int16_t DS18B20_read_temp(uint8_t sensor_type);

#define OW_CRC_ERROR	0x270F		// = 9999 dez
#define OW_NO_SENSOR	0x271F		// = 10015 dez

#endif